MockedEndpoint

Struct MockedEndpoint 

pub struct MockedEndpoint { /* private fields */ }
Available on test and crate feature mock_tests only.
A mocked HTTP Endpoint.

It asserts the request body and headers and returns a response

Implementations

Source

impl MockedEndpoint

pub fn new(res_code: u16) -> Self

Available on docsrs only.
pub fn assert_body<B: Into<BodyMock>>(&mut self, body: B)

Available on docsrs only.
pub fn set_response<B: Into<BodyMock>>(&mut self, code: u16, body: B)

Available on docsrs only.
pub fn set_response_status(&mut self, code: u16)

Available on docsrs only.
pub fn add_response_header<N, V, E1, E2>( &mut self, name: N, value: V, ) -> Result<(), ErrorImp>
where N: TryInto<HeaderName, Error = E1>, V: TryInto<HeaderValue, Error = E2>, ErrorImp: From<E1> + From<E2>,

Available on docsrs only.

Add a single header to the response If the map did have this key present, the new value is pushed to the end of the list of values

pub fn add_header_assertion<N, V, E1, E2>( &mut self, name: N, value: V, ) -> Result<(), ErrorImp>
where N: TryInto<HeaderName, Error = E1>, V: TryInto<HeaderValue, Error = E2>, ErrorImp: From<E1> + From<E2>,

Available on docsrs only.

Check a single header of the request If the map did have this key present, the new value is pushed to the end of the list of values